@@ -374,9 +374,12 @@ def test(
 
 
 @app.command("init", help="Initialize a new serverless project.")
-def app_create(project_name: str):
+def app_create(
+    project_name: str,
+    headless: bool = typer.Option(True, "--headless", help="Run in headless mode."),
+):
     try:
-        creator = ApplicationService(project_name)
+        creator = ApplicationService(project_name, headless=headless)
         creator.create_app()
     except Exception as e:
         print(f"Error initializing serverless project: {e}")
