@@ -23,24 +23,7 @@ class ResponseService:
         )
 
     def create_response_file(self):
-        if not os.path.exists(
-            os.path.join(
-                self.current_directory, self.parent_folder, self.destination_folder
-            )
-        ):
-            try:
-                os.makedirs(
-                    os.path.join(
-                        self.current_directory,
-                        self.parent_folder,
-                        self.destination_folder,
-                    )
-                )
-                print(f"Created '{self.destination_folder}' folder.")
-            except OSError as e:
-                print(f"Error creating directory: {e}")
-                return
-
+        self.create_destination_folder()
         if not os.path.exists(self.file_path):
             try:
                 with open(self.source_stub, "r") as source_file:
@@ -52,13 +35,7 @@ class ResponseService:
                 print(f"An error occurred while reading the stub file: {e}")
                 return
 
-            updated_content = handler_stub_content.replace("{{file_name}}", self.name)
-            updated_content = updated_content.replace(
-                "{{class_name_title_case_singular}}", self.name.capitalize()
-            )
-            updated_content = updated_content.replace(
-                "{{class_name_lower_case_plural}}", self.name.lower() + "s"
-            )
+            updated_content = self.update_stub_content(handler_stub_content)
 
             try:
                 with open(self.file_path, "w") as destination_file:
@@ -78,3 +55,25 @@ class ResponseService:
                 print(f"An error occurred while trying to delete the file: {e}")
         else:
             print(f'File "{self.file_path}" does not exist. No deletion needed.')
+
+    def create_destination_folder(self):
+        destination_folder_path = os.path.join(
+            self.current_directory, self.parent_folder, self.destination_folder
+        )
+        if not os.path.exists(destination_folder_path):
+            try:
+                os.makedirs(destination_folder_path)
+                print(f"Created '{self.destination_folder}' folder.")
+            except OSError as e:
+                print(f"Error creating directory: {e}")
+                return
+
+    def update_stub_content(self, handler_stub_content):
+        updated_content = handler_stub_content.replace("{{file_name}}", self.name)
+        updated_content = updated_content.replace(
+            "{{class_name_title_case_singular}}", self.name.capitalize()
+        )
+        updated_content = updated_content.replace(
+            "{{class_name_lower_case_plural}}", self.name.lower() + "s"
+        )
+        return updated_content
